@@ -1,8 +1,8 @@
 # for roxygen2 documentation please edit file R/data.R!
-arthropodtraits <- utils::read.csv(url("https://v1.datadryad.org/bitstream/handle/10255/dryad.76638/ArthropodSpeciesTraits.txt?sequence=1", 
+arthropodtraits <- utils::read.csv(url("https://datadryad.org/stash/downloads/file_stream/41660", 
                                        encoding = "latin1"), 
                                    sep = "\t",
-                                   stringsAsFactors = TRUE
+                                   stringsAsFactors = FALSE
 )
 
 levels(arthropodtraits$Author) <- iconv(levels(arthropodtraits$Author), to = "UTF-8")
